@@ -28,7 +28,9 @@ pub use node_addr::ZmqType;
 pub use node_addr::{
     NodeAddr, PartialNodeAddr, RemoteNodeAddr, ToNodeAddr, ToRemoteNodeAddr,
 };
-pub use noise::{NoiseDecryptor, NoiseEncryptor, NoiseTranscoder};
+pub use noise::{
+    HandshakeError, NoiseDecryptor, NoiseEncryptor, NoiseTranscoder,
+};
 pub use session::{Input, Output, Raw, RawInput, RawOutput, Session, Split};
 pub use transcoders::{
     Decrypt, DecryptionError, Encrypt, PlainTranscoder, Transcode,
