@@ -11,11 +11,9 @@
 // along with this software.
 // If not, see <https://opensource.org/licenses/MIT>.
 
-use bitcoin::secp256k1;
-
-use bitcoin::hashes::sha256::Hash as Sha256;
-use bitcoin::hashes::{Hash, HashEngine};
-use bitcoin::secp256k1::{PublicKey, SecretKey};
+use bitcoin_hashes::sha256::Hash as Sha256;
+use bitcoin_hashes::{Hash, HashEngine};
+use secp256k1::{PublicKey, SecretKey};
 
 use super::act::{
     Act, ActBuilder, ACT_ONE_LENGTH, ACT_THREE_LENGTH, ACT_TWO_LENGTH,
@@ -39,7 +37,9 @@ macro_rules! concat_then_sha256 {
 	}}
 }
 
-#[derive(Debug, Display, Error, From, PartialEq)]
+#[derive(
+    Debug, Clone, PartialOrd, Ord, PartialEq, Eq, Hash, Display, Error, From,
+)]
 #[display(Debug)]
 pub enum HandshakeError {
     #[from]
@@ -672,10 +672,8 @@ mod test {
     use super::HandshakeState::*;
     use super::*;
 
-    use bitcoin::hashes::hex::{FromHex, ToHex};
-
-    use bitcoin::secp256k1;
-    use bitcoin::secp256k1::{PublicKey, SecretKey};
+    use bitcoin_hashes::hex::{FromHex, ToHex};
+    use secp256k1::{PublicKey, SecretKey};
 
     struct TestCtx {
         initiator: HandshakeState,
